==> rong-ui-react-0.0.1.tgz: package/es/checkbox/checkbox.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

var _excluded = ["children", "style", "className"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } Object.defineProperty(subClass, "prototype", { value: Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }), writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import RcCheckbox from '../rc-checkbox';
import Group from './group';
import { classNames } from '../_util/assist';
import { Consumer } from './groupContext';
import './style/checkbox.less';
var prefixCls = 'r-checkbox';

var Checkbox = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(Checkbox, _React$PureComponent);

  var _super = _createSuper(Checkbox);

  function Checkbox(props) {
    var _this;

    _classCallCheck(this, Checkbox);

    _this = _super.call(this, props);

    _defineProperty(_assertThisInitialized(_this), "onRcCheckboxChange", function (e) {
      _this.setState({
        checked: e.target.checked
      }, function () {
        _this.props.onChange && _this.props.onChange(e);
        _this.group && _this.group.onChange(e);
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onRcCheckboxUpdated", function (RcCheckbox) {
      _this.setState({
        checked: RcCheckbox.state.checked
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onRcCheckboxMounted", function (RcCheckbox) {
      _this.setState({
        checked: RcCheckbox.state.checked
      });
    });

    _this.state = {
      checked: false
    };
    return _this;
  }

  _createClass(Checkbox, [{
    key: "wrapCls",
    get: function get() {
      var _ref;

      var _this$props = this.props,
          className = _this$props.className,
          disabled = _this$props.disabled;
      return classNames([prefixCls, className, (_ref = {}, _defineProperty(_ref, "".concat(prefixCls, "-checked"), this.state.checked), _defineProperty(_ref, "".concat(prefixCls, "-required"), disabled), _ref)]);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.group && this.group.fields.push(this);
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props2 = this.props,
          children = _this$props2.children,
          style = _this$props2.style,
          className = _this$props2.className,
          restProps = _objectWithoutProperties(_this$props2, _excluded);

      console.log('checkbox mounted or update');
      return /*#__PURE__*/React.createElement(Consumer, null, function (context) {
        _this2.group = context;

        if (_this2.group) {
          restProps.checked = _this2.group.value.indexOf(_this2.props.value) !== -1;
          restProps.name = restProps.name || _this2.group.name;
          restProps.disabled = restProps.disabled || _this2.group.disabled;
        }

        return /*#__PURE__*/React.createElement("label", {
          className: _this2.wrapCls,
          style: style
        }, /*#__PURE__*/React.createElement(RcCheckbox, _extends({}, restProps, {
          onChange: _this2.onRcCheckboxChange,
          onMounted: _this2.onRcCheckboxMounted,
          onUpdated: _this2.onRcCheckboxUpdated
        })), /*#__PURE__*/React.createElement("span", null, children));
      });
    }
  }]);

  return Checkbox;
}(React.PureComponent);

Checkbox.Group = Group;
export default Checkbox;

==> rong-ui-react-0.0.5.tgz: package/es/checkbox/checkbox.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

var _excluded = ["children", "style", "className"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from 'react';
import RcCheckbox from '../rc-checkbox';
import Group from './group';
import { classNames } from '../_util/assist';
import { Consumer } from './groupContext';
var prefixCls = 'r-checkbox';

var Checkbox = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(Checkbox, _React$PureComponent);

  var _super = _createSuper(Checkbox);

  function Checkbox(props) {
    var _this;

    _classCallCheck(this, Checkbox);

    _this = _super.call(this, props);

    _this.onRcCheckboxChange = function (e) {
      _this.setState({
        checked: e.target.checked
      }, function () {
        _this.props.onChange && _this.props.onChange(e);
        _this.group && _this.group.onChange(e);
      });
    };

    _this.onRcCheckboxUpdated = function (RcCheckbox) {
      _this.setState({
        checked: RcCheckbox.state.checked
      });
    };

    _this.onRcCheckboxMounted = function (RcCheckbox) {
      _this.setState({
        checked: RcCheckbox.state.checked
      });
    };

    _this.state = {
      checked: false
    };
    return _this;
  }

  _createClass(Checkbox, [{
    key: "wrapCls",
    get: function get() {
      var _ref;

      var _this$props = this.props,
          className = _this$props.className,
          disabled = _this$props.disabled;
      return classNames([prefixCls, className, (_ref = {}, _defineProperty(_ref, "".concat(prefixCls, "-checked"), this.state.checked), _defineProperty(_ref, "".concat(prefixCls, "-required"), disabled), _ref)]);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.group && this.group.fields.push(this);
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props2 = this.props,
          children = _this$props2.children,
          style = _this$props2.style,
          className = _this$props2.className,
          restProps = _objectWithoutProperties(_this$props2, _excluded);

      console.log('checkbox mounted or update');
      return /*#__PURE__*/React.createElement(Consumer, null, function (context) {
        _this2.group = context;

        if (_this2.group) {
          restProps.checked = _this2.group.value.indexOf(_this2.props.value) !== -1;
          restProps.name = restProps.name || _this2.group.name;
          restProps.disabled = restProps.disabled || _this2.group.disabled;
        }

        return /*#__PURE__*/React.createElement("label", {
          className: _this2.wrapCls,
          style: style
        }, /*#__PURE__*/React.createElement(RcCheckbox, _extends({}, restProps, {
          onChange: _this2.onRcCheckboxChange,
          onMounted: _this2.onRcCheckboxMounted,
          onUpdated: _this2.onRcCheckboxUpdated
        })), /*#__PURE__*/React.createElement("span", null, children));
      });
    }
  }]);

  return Checkbox;
}(React.PureComponent);

Checkbox.Group = Group;
export default Checkbox;
